@@ -1,4 +1,5 @@
-print.clos <- function(x, ...) {
+"print.clos" <-
+function(x, ...) {
 ## ----------------------------------------------------------------------------
 ## Title: print.clos
 ## ----------------------------------------------------------------------------
@@ -100,3 +101,4 @@ print.clos <- function(x, ...) {
   cat("\n")
   
 } ## end of function print.clos
+
